package paquetGameUI;
import java.awt.Graphics;
import java.awt.Image;
import javax.swing.ImageIcon;

/**
 * La classe Bomb représente une bombe dans le jeu.
 */
public class Bomb {
    private int x, y;
    private final Image bombImage;
    private int timer;
    private boolean exploded;

    /**
     * Constructeur de la classe Bomb.
     * @param startX La position initiale en X de la bombe.
     * @param startY La position initiale en Y de la bombe.
     */
    public Bomb(int startX, int startY) {
        this.x = startX;
        this.y = startY;
        this.bombImage = new ImageIcon("paquetGameUI/images/bombe.png").getImage();
        this.timer = 100;  // Ajuster la valeur du timer si nécessaire
        this.exploded = false;
    }

    /**
     * Met à jour l'état de la bombe.
     * Réduit le timer et fait exploser la bombe lorsque le timer atteint zéro.
     */
    public void update() {
        if (timer > 0) {
            timer--;
        } else {
            exploded = true;
        }
    }

    /**
     * Dessine la bombe sur le graphique spécifié.
     * @param g Le contexte graphique.
     * @param tileSize La taille de la tuile.
     * @param offsetX Le décalage en X.
     * @param offsetY Le décalage en Y.
     */
    public void draw(Graphics g, int tileSize, int offsetX, int offsetY) {
        if (!exploded) {
            g.drawImage(bombImage, x * tileSize + offsetX, y * tileSize + offsetY, tileSize, tileSize, null);
        }
    }

    /**
     * Vérifie si la bombe a explosé.
     * @return true si la bombe a explosé, false sinon.
     */
    public boolean hasExploded() {
        return exploded;
    }

    /**
     * Obtient la position en X de la bombe.
     * @return La position en X.
     */
    public int getX() {
        return x;
    }

    /**
     * Obtient la position en Y de la bombe.
     * @return La position en Y.
     */
    public int getY() {
        return y;
    }
}
