package paquetGameUI;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class RoomLoader {

    /**
     * Charge une liste de salles à partir des fichiers spécifiés.
     *
     * @param fileNames Un tableau de noms de fichiers contenant les données des salles.
     * @return Une liste d'objets Room représentant les salles chargées.
     */
    public static List<Room> loadRooms(String[] fileNames) {
        List<Room> rooms = new ArrayList<>();

        for (String fileName : fileNames) {
            System.out.println("Loading room file: " + fileName); // Ajouter une journalisation
            try (BufferedReader br = new BufferedReader(new FileReader(fileName))) {
                List<String> lines = new ArrayList<>();
                String line;
                while ((line = br.readLine()) != null) {
                    lines.add(line);
                }

                int rowCount = lines.size();
                int colCount = lines.get(0).length();
                int[][] layout = new int[rowCount][colCount];

                for (int y = 0; y < rowCount; y++) {
                    String row = lines.get(y);
                    for (int x = 0; x < colCount; x++) {
                        char ch = row.charAt(x);
                        switch (ch) {
                            case '#':
                                layout[y][x] = 1;
                                break;
                            case 'J':
                                layout[y][x] = 3;
                                break;
                            case 'E':
                                layout[y][x] = 2;
                                break;
                            case 'X':
                                layout[y][x] = 4;
                                break;
                            case 'D': // Diamant
                                layout[y][x] = 6;
                                break;
                            case '1': // Clé de salle
                                layout[y][x] = 7;
                                break;
                            case 'P': // Clé de niveau
                                layout[y][x] = 8;
                                break;
                            case 'T': // Trésor
                                layout[y][x] = 9;
                                break;
                            case 'C': // Couronne
                                layout[y][x] = 10;
                                break;
                            case 'B': // Bague
                                layout[y][x] = 11;
                                break;
                            case 'K': // Monstre 1 KORO
                                layout[y][x] = 12;
                                break;
                            case 'N': // Monstre 2 NATSU
                                layout[y][x] = 13;
                                break;
                            case 'O': // Monstre 3 CHREK
                                layout[y][x] = 14;
                                break;
                            case 'S': // Monstre 4 SERPENT DE MER
                                layout[y][x] = 15;
                                break;
                            default:
                                layout[y][x] = 0;
                                break;
                        }
                    }
                }

                rooms.add(new Room(layout));
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

        return rooms;
    }
}
