package paquetMain;

import paquetException.MonException;
import paquetGameUI.*;
import paquetTerminal.TerminalGame;
import javax.swing.*;

import java.io.IOException;
import java.util.Scanner;

/**
 * Classe principale du programme qui permet de choisir entre une interface graphique (UI) ou une interface terminal (T) pour jouer.
 */
public class Main {

    /**
     * Point d'entrée du programme.
     * @param args Les arguments de la ligne de commande.
     * @throws IOException Si une erreur d'entrée/sortie se produit.
     * @return void Cette méthode ne retourne aucune valeur.
     */
    public static void main(String[] args) throws IOException {
        Scanner scanner = new Scanner(System.in);
        System.out.println("Voulez-vous jouer en version graphique (UI) ou sur le terminal (T) ?");
        String choice = scanner.nextLine();

        if (choice.equalsIgnoreCase("UI")) {
            SwingUtilities.invokeLater(() -> {
                JFrame frame = new JFrame("Menu du Jeu");
                MenuPanel menuPanel = new MenuPanel();
                frame.add(menuPanel);
                frame.pack();
                frame.setSize(800, 600);
                frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
                frame.setVisible(true);
            });
        } else if (choice.equalsIgnoreCase("T")) {
            try {
                TerminalGame game = new TerminalGame();
                game.start();
            } catch (MonException e) {
                System.out.println("Erreur: " + e.getMessage());
            }
        } else {
            System.out.println("Choix invalide. Veuillez relancer le programme et choisir 'UI' ou 'T'.");
        }

        scanner.close();
    }
}
